<?php
/*
 * Plugin Name: Rupt: Account sharing monitoring and prevention
 * Plugin URI: https://www.rupt.dev
 * Description: Account sharing monitoring and prevention for WordPress brought to you by Rupt.
 * Version: 1.0.1
 * Author: Rupt
 * License: GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */


function rupt_plugin_activation()
{
    // do nothing
}

function rupt_plugin_deactivation()
{
    // do nothing
}

function rupt_plugin_uninstall()
{
    // do nothing
}

register_activation_hook(
    __FILE__,
    'rupt_plugin_activation'
);

register_deactivation_hook(__FILE__, 'rupt_plugin_deactivation');

register_uninstall_hook(
    __FILE__,
    'rupt_plugin_uninstall'
);

function rupt_embed_script()
{
    $logout_url = get_site_url() . '/wp-login.php?action=logout&rupt=logout';
    $client_id = get_option('rupt_client_id');
    $new_account_url = get_option('rupt_new_account_url', $logout_url);
    $phone_number_key = get_option('rupt_phone_number_key');
    $user_id = get_current_user_id();
    $user_info = get_userdata($user_id);
    $phone_number_meta = $phone_number_key ? get_user_meta($user_id, $phone_number_key, true) : '';
    if ($user_info) {
        $email = $user_info->user_email;

        if (isset($client_id) && isset($user_id)) {
            echo "<script type='text/JavaScript'>
            if ($user_id) {
            const script = document.createElement('script');
            script.src = 'https://unpkg.com/rupt@latest/index.js';
            script.async = true;
            script.addEventListener('load', (event) => {
                window.Rupt.attach({
                client_id: '$client_id',
                account: '$user_id',
                email: '$email',
                phone: '$phone_number_meta',
                redirect_urls: {
                    logout_url: '$logout_url',
                    new_account_url: '$new_account_url',
                },
                });
            });
            document.head.appendChild(script);
            }
            </script>";
        }
    }
}

add_action('wp_head', 'rupt_embed_script');

function rupt_settings_init()
{
    // register a new setting for "general" page
    register_setting('general', 'rupt_client_id');
    register_setting('general', 'rupt_new_account_url');
    register_setting('general', 'rupt_phone_number_key');

    // register a new section in the "general" page
    add_settings_section(
        'rupt_settings_section',
        'Rupt Settings',
        'rupt_settings_section_callback',
        'general'
    );

    // register a new field in the "rupt_settings_section" section, inside the "general" page
    add_settings_field(
        'rupt_client_id',
        'Client ID',
        'rupt_client_id_callback',
        'general',
        'rupt_settings_section'
    );

    add_settings_field(
        'rupt_new_account_url',
        'New Account URL',
        'rupt_new_account_url_callback',
        'general',
        'rupt_settings_section'
    );

    add_settings_field(
        'rupt_phone_number_key',
        'Phone Number Key',
        'rupt_phone_number_key_callback',
        'general',
        'rupt_settings_section'
    );
}

/**
 * register rupt_settings_init to the admin_init action hook
 */
add_action('admin_init', 'rupt_settings_init');

function rupt_custom_logout()
{
    if(isset($_GET['rupt']) && $_GET['rupt'] === 'logout') {
        wp_logout();
        wp_redirect(home_url());
        exit;
    };  
}

add_action('init', 'rupt_custom_logout');

/**
 * callback functions
 */

// section content cb
function rupt_settings_section_callback()
{
    echo '<p>The account sharing monitoring and prevention settings for your Rupt dashboard.</p>';
}

// field content cb
function rupt_client_id_callback()
{
    // get the value of the setting we've registered with register_setting()
    $setting = get_option('rupt_client_id');
    // output the field
?>
    <input type="text" name="rupt_client_id" value="<?php echo isset($setting) ? esc_attr($setting) : ''; ?>">
<?php
}

function rupt_new_account_url_callback()
{
    // get the value of the setting we've registered with register_setting()
    $setting = get_option('rupt_new_account_url');
    // output the field
?>
    <input type="text" name="rupt_new_account_url" value="<?php echo isset($setting) ? esc_attr($setting) : ''; ?>">
<?php
}

function rupt_phone_number_key_callback()
{
    // get the value of the setting we've registered with register_setting()
    $setting = get_option('rupt_phone_number_key');
    // output the field
?>
    <input type="text" name="rupt_phone_number_key" value="<?php echo isset($setting) ? esc_attr($setting) : ''; ?>">
<?php
}

